aboutsummaryrefslogtreecommitdiff
path: root/build/cxx
diff options
context:
space:
mode:
authorBoris Kolpackov <boris@codesynthesis.com>2015-07-01 16:45:34 +0200
committerBoris Kolpackov <boris@codesynthesis.com>2015-07-01 16:45:34 +0200
commite4c4fec8c9097722ee5ee94f2ce5ad0313ed8d7b (patch)
treee8de68957fc5cd00bb7b0b3199ca8a9abba4f678 /build/cxx
parentf7e9830c0c413f05737002dcc8d06e73cb379980 (diff)
Clean up group state, mtime design
Diffstat (limited to 'build/cxx')
-rw-r--r--build/cxx/rule.cxx4
1 files changed, 2 insertions, 2 deletions
diff --git a/build/cxx/rule.cxx b/build/cxx/rule.cxx
index 08a9202..7547201 100644
--- a/build/cxx/rule.cxx
+++ b/build/cxx/rule.cxx
@@ -650,13 +650,13 @@ namespace build
// expensive. At the same time, most of these headers are
// existing files that we will never be updating (again,
// system headers, for example) and the rule that will match
// them is fallback path_rule. So we are going to do a little
// fast-path optimization by detecting this common case.
//
recipe_function* const* recipe (
pt.recipe (a).target<recipe_function*> ());
- if (recipe == nullptr || *recipe != &path_rule::perform_update)
+ if (recipe == nullptr || *recipe != &file_rule::perform_update)
{
// We only want to restart if our call to execute() actually
// caused an update. In particular, the target could already
@@ -650,13 +650,13 @@ namespace build
// existing files that we will never be updating (again,
// system headers, for example) and the rule that will match
- // them is fallback path_rule. So we are going to do a little
+ // them is fallback file_rule. So we are going to do a little
// fast-path optimization by detecting this common case.
//